soakdb3
=======================================================================

XChem replacement for soakdb2, including a new database backend.

..
    Anything below this line is used when viewing README.rst and will be replaced
    when included in index.rst



Documentation
-----------------------------------------------------------------------

See http://www.cs.diamond.ac.uk/reports/gitlab-ci/soakdb3/index.html for more detailed documentation.

